package com.colinwyattwarren.tictactwice;

public class GameController {
	private PlayGameActivity mActivity;
	private Board mBoard1;
	private Board mBoard2;
	private Board.Player mCurrentPlayer;
	private int mMoves;
	
	public GameController(PlayGameActivity activity, Board board1, Board board2) {
		mActivity = activity;
		mBoard1 = board1;
		mBoard2 = board2;
		mCurrentPlayer = Board.Player.A;
		mMoves = 0;
	}
	
	/**
	 * Places a piece on the game board.
	 * @param square The square the piece is being placed on
	 */
	public void placePiece(Board.SquareType square) {
		// Check if there's already a piece on the square
		if (mBoard1.squareHasPiece(square)) {
			mActivity.toast("There is already a piece on that square!");
			return;
		}
		
		// Update boards
		mBoard1.placePiece(mCurrentPlayer, square);
		mBoard2.placePiece(mCurrentPlayer, square);
		
		// Update UI
		mActivity.boardsChanged();
		
		// Check for winner
		Board.Player board1Winner = mBoard1.getWinner();
		Board.Player board2Winner = mBoard2.getWinner();
		boolean hasWinner = (board1Winner != null) || (board2Winner != null);
		
		if (hasWinner) { // There's a winner
			Board.Player winner = (board1Winner != null)? board1Winner : board2Winner;
			mActivity.onWin(winner);
			return; // If there's a winner, we don't need to continue.
		}
		
		// Increment the moves counter
		mMoves++;
		
		// If there have been more than 16 movies, end the game with a stalemate
		if (mMoves >= 16) {
			mActivity.onStalemate();
			return;
		}
		
		// It's the other person's turn
		nextPlayer();
	}
	
	/**
	 * Changes the game state to the next player.
	 */
	private void nextPlayer() {
		switch(mCurrentPlayer) {
		case A:
			mCurrentPlayer = Board.Player.B;
			break;
		case B:
			mCurrentPlayer = Board.Player.A;
			break;
		}
	}
}
