package com.colinwyattwarren.tictactwice;

import android.os.Bundle;
import android.app.Activity;
import android.content.Intent;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.Toast;
import android.support.v4.app.NavUtils;

public class PlayGameActivity extends Activity {
	public final static String HAS_WINNER = "com.colinwyattwarren.tictactwice.HAS_WINNER";
	public final static String WINNER_NAME = "com.colinwyattwarren.tictactwice.WINNER_NAME";
	
	private Board mBoard1;
	private Board mBoard2;
	
	private GameBoard mGameBoard1;
	private GameBoard mGameBoard2;
	
	private GameController mGameController;
	
	private String mPlayerAName;
	private String mPlayerBName;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_play_game);
		// Show the Up button in the action bar.
		getActionBar().setDisplayHomeAsUpEnabled(true);
		
		// Get the player names
		Intent intent = getIntent();
		mPlayerAName = intent.getExtras().getString(NewGameActivity.PLAYER_A_NAME);
		mPlayerBName = intent.getExtras().getString(NewGameActivity.PLAYER_B_NAME);
		
		// Initialize the boards
		mBoard1 = new Board(true);
		mBoard2 = new Board(false);
		
		// Get the UI elements
		mGameBoard1 = (GameBoard) findViewById(R.id.gameBoard1);
		mGameBoard2 = (GameBoard) findViewById(R.id.gameBoard2);
		
		// Link up the UI to the data
		mGameBoard1.setBoard(mBoard1);
		mGameBoard2.setBoard(mBoard2);
		
		// Link up the controller to everything
		mGameController = new GameController(this, mBoard1, mBoard2);
		mGameBoard1.setGameController(mGameController);
		mGameBoard2.setGameController(mGameController);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.activity_play_game, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case android.R.id.home:
			// This ID represents the Home or Up button. In the case of this
			// activity, the Up button is shown. Use NavUtils to allow users
			// to navigate up one level in the application structure. For
			// more details, see the Navigation pattern on Android Design:
			//
			// http://developer.android.com/design/patterns/navigation.html#up-vs-back
			//
			NavUtils.navigateUpFromSameTask(this);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
	
	/**
	 * Called by GameController to signal that one player has won.
	 * @param winner The winner
	 */
	public void onWin(Board.Player winner) {
		Intent intent = new Intent(this, GameFinishedActivity.class);
		String winnerName = "ERR: UNKNOWN PLAYER";
		switch(winner) {
		case A:
			winnerName = mPlayerAName;
			break;
		case B: 
			winnerName = mPlayerBName;
			break;
		}
		intent.putExtra(HAS_WINNER, true);
		intent.putExtra(WINNER_NAME, winnerName);
		startActivity(intent);
	}
	
	/**
	 * Called by GameController to signal that there is a stalemate.
	 */
	public void onStalemate() {
		Intent intent = new Intent(this, GameFinishedActivity.class);
		intent.putExtra(HAS_WINNER, false);
		startActivity(intent);
	}
	
	/**
	 * Update the board UI
	 */
	public void boardsChanged() {
		mGameBoard1.boardChanged();
		mGameBoard2.boardChanged();
	}
	
	public void toast(String str) {
		Toast toast = Toast.makeText(
				getApplicationContext(),
				str,
				Toast.LENGTH_SHORT);
		toast.show();
	}

}
